@@ -4,7 +4,8 @@ pytest -v --rootdir . --junitxml data/pytest.xml -o 'junit_family = xunit2' \
   --deselect test_runBatchExamples.py::test_runBatchBlender \
   --deselect  test_runBatchExamples.py::test_runBatchPuppeteerLighthouse \
   --deselect  test_runBatchExamples.py::test_runBatchTaurus \
-  --ignore DevWeb
+  --ignore DevWeb \
+  --ignore go
 
 #   --deselect  test_runBatchExamples.py::test_runBatchPython
 #   --deselect test_runBatchExamples.py::test_runBatchJMeter \
